"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenBucketRateLimiter = exports.RateLimiter = void 0;
const bottleneck_1 = __importDefault(require("bottleneck"));
class RateLimiter {
    limiter;
    constructor(maxRequests, perMilliseconds) {
        this.limiter = new bottleneck_1.default({
            maxConcurrent: maxRequests,
            minTime: perMilliseconds / maxRequests,
        });
    }
    schedule(fn, ...args) {
        return this.limiter.schedule(() => fn(...args));
    }
}
exports.RateLimiter = RateLimiter;
class TokenBucketRateLimiter {
    tokens;
    capacity;
    refillRate;
    lastRefillTimestamp;
    constructor(maxQueriesPerSecond) {
        this.capacity = maxQueriesPerSecond;
        this.tokens = maxQueriesPerSecond;
        this.refillRate = maxQueriesPerSecond / 1000;
        this.lastRefillTimestamp = Date.now();
    }
    refillTokens() {
        const now = Date.now();
        const elapsedTime = now - this.lastRefillTimestamp;
        const newTokens = elapsedTime * this.refillRate;
        this.tokens = Math.min(this.capacity, this.tokens + newTokens);
        this.lastRefillTimestamp = now;
    }
    async acquire() {
        this.refillTokens();
        while (this.tokens < 1) {
            await new Promise((resolve) => setTimeout(resolve, 10));
            this.refillTokens();
        }
        this.tokens -= 1;
    }
}
exports.TokenBucketRateLimiter = TokenBucketRateLimiter;
//# sourceMappingURL=RateLimiter.js.map