"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkerManager = void 0;
const bullmq_1 = require("bullmq");
const RedisClient_1 = require("../utils/RedisClient");
const NotifierRegistry_1 = require("./NotifierRegistry");
const ResponseTrackers_1 = require("../utils/ResponseTrackers");
const Logger_1 = __importDefault(require("../utils/Logger"));
class WorkerManager {
    config;
    worker;
    constructor(config) {
        this.config = config;
        this.worker = new bullmq_1.Worker(this.config.queueName, this.jobProcessor.bind(this), {
            connection: {
                ...RedisClient_1.RedisClient.getInstance().options,
                maxRetriesPerRequest: null,
                enableReadyCheck: false,
            },
            concurrency: this.config.concurrency || 10,
        });
        this.worker.on("completed", (job) => {
            Logger_1.default.log(`✅ Job completed successfully: ${job.id}`);
        });
        this.worker.on("failed", (job, error) => {
            Logger_1.default.error(`❌ Job failed (${job?.id}):`, error);
        });
        Logger_1.default.log(`🚀 Worker started listening on queue "${this.config.queueName}"`);
    }
    async jobProcessor(job) {
        const { userIds, channel, meta, trackResponses, trackingKey } = job.data;
        const notifier = NotifierRegistry_1.NotifierRegistry.get(channel);
        try {
            const response = await notifier.send(userIds, meta);
            if (trackResponses && response) {
                await (0, ResponseTrackers_1.trackNotificationResponse)(trackingKey, response);
            }
        }
        catch (error) {
            Logger_1.default.error(`❌ Notification failed: ${error.message}`);
            if (trackResponses) {
                await (0, ResponseTrackers_1.trackNotificationResponse)(trackingKey, {
                    success: false,
                    error: error.message,
                });
            }
        }
    }
    async close() {
        await this.worker.close();
    }
}
exports.WorkerManager = WorkerManager;
//# sourceMappingURL=WorkerManager.js.map