"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TelegramNotifier = void 0;
const telegraf_1 = require("telegraf");
const RateLimiter_1 = require("../../core/RateLimiter");
const Logger_1 = __importDefault(require("../../utils/Logger"));
class TelegramNotifier {
    config;
    bot;
    rateLimiter;
    constructor(config) {
        this.config = config;
        this.bot = new telegraf_1.Telegraf(config.botToken);
        this.rateLimiter = new RateLimiter_1.RateLimiter(config.maxMessagesPerSecond || 25, 1000);
    }
    async send(users, meta) {
        const results = [];
        const maxConcurrentMessages = 5;
        let activeSends = [];
        for (let i = 0; i < users.length; i++) {
            const user = users[i];
            const extraOptions = meta[i] || {};
            const sendOptions = {
                parse_mode: "MarkdownV2",
                ...extraOptions,
            };
            const messageText = meta[i]?.text || "No message content provided.";
            const sendTask = this.rateLimiter.schedule(async () => {
                try {
                    const response = await this.bot.telegram.sendMessage(user, messageText, sendOptions);
                    Logger_1.default.log(`📨 Telegram message sent to ${user}:`, response);
                    results.push({ status: "success", recipient: user, response });
                }
                catch (error) {
                    Logger_1.default.error(`❌ Telegram Error (User ${user}):`, error.message);
                    results.push({
                        status: "failed",
                        recipient: user,
                        error: error.message,
                    });
                }
            });
            activeSends.push(sendTask);
            if (activeSends.length >= maxConcurrentMessages) {
                await Promise.race(activeSends);
                activeSends = activeSends.filter((task) => !task.finally);
            }
        }
        await Promise.all(activeSends);
        return results;
    }
}
exports.TelegramNotifier = TelegramNotifier;
//# sourceMappingURL=TelegramNotifier.js.map