"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.startWorkerServer = startWorkerServer;
const RedisClient_1 = require("./RedisClient");
const NotifierRegistry_1 = require("../core/NotifierRegistry");
const TelegramNotifier_1 = require("../jobs/channels/TelegramNotifier");
const WorkerManager_1 = require("../core/WorkerManager");
const EmailNotifier_1 = require("../jobs/channels/EmailNotifier");
const FirebaseNotifier_1 = require("../jobs/channels/FirebaseNotifier");
const WebPushNotifier_1 = require("../jobs/channels/WebPushNotifier");
const Logger_1 = __importDefault(require("./Logger"));
function startWorkerServer(config) {
    RedisClient_1.RedisClient.setInstance(config.redisInstance);
    const notifierMap = {
        telegram: TelegramNotifier_1.TelegramNotifier,
        email: EmailNotifier_1.EmailNotifier,
        firebase: FirebaseNotifier_1.FirebaseNotifier,
        web: WebPushNotifier_1.WebPushNotifier,
    };
    for (const [channel, options] of Object.entries(config.notifiers || {})) {
        if (notifierMap[channel]) {
            NotifierRegistry_1.NotifierRegistry.register(channel, new notifierMap[channel](options));
            Logger_1.default.log(`✅ Registered notifier: ${channel}`);
        }
        else {
            Logger_1.default.log(`⚠️ Unknown notifier type: ${channel}, skipping registration.`);
        }
    }
    new WorkerManager_1.WorkerManager({
        queueName: config.queueName,
        concurrency: config.concurrency || 10,
    });
    Logger_1.default.log(`🚀 Worker server started on queue: '${config.queueName}'`);
}
//# sourceMappingURL=StartWorkerServer.js.map